Skip to contents

Returns a step-builder function that resolves source paths relative to a local directory. The directory path is resolved to an absolute path at creation time.

Usage

from_dir(path)

Arguments

path

Path to the directory. Resolved to absolute via fs::path_abs() at creation time. Must exist.

Value

A function with signature function(source, dest, strategy = "overwrite", data = NULL) that returns a step_file() object.