Skip to content

Prints the R code that would reproduce the given theme via cat(), and returns the code invisibly as a single character string.

Usage

theme_code(theme)

Arguments

theme

A prefab_theme object. Unlike use_theme(), create_project(), and launch_project(), this does not accept a path to a directory of template files; pass theme_from_dir() the path instead.

Value

The generated R code as a single character string (invisibly).