Skip to content

Discovers the project root and executes the theme against it.

Usage

use_theme(theme)

Arguments

theme

A prefab_theme object created by new_theme(), theme_from_dir(), or a pre-set theme function, or a path to a directory of template files.

Value

The project root path (invisibly).

See also

theme_from_dir() for how a template directory is read.

Examples

if (FALSE) { # \dontrun{
use_theme(r_analysis())
use_theme(r_analysis() + claude_r_analysis())

# A directory of template files
use_theme("~/my-template")
} # }