Skip to contents

Creates a new project directory and applies a theme to it. If RStudio is available, opens the new project in a new session.

Usage

create_project(path, theme)

Arguments

path

Path for the new project directory. Resolved to an absolute path via fs::path_abs().

theme

A prefab_theme object created by new_theme() or a pre-set theme function.

Value

The normalized project path (invisibly).

Examples

if (FALSE) { # \dontrun{
create_project("~/projects/my-analysis", r_analysis())
create_project("my-targets-project", r_targets() + claude_r_targets())
} # }