Creates a new project directory and applies a theme to it. If RStudio is available, opens the new project in a new session.
Arguments
- path
Path for the new project directory. Resolved to an absolute path via
fs::path_abs().- theme
A
prefab_themeobject created bynew_theme()or a pre-set theme function.
Examples
if (FALSE) { # \dontrun{
create_project("~/projects/my-analysis", r_analysis())
create_project("my-targets-project", r_targets() + claude_r_targets())
} # }