Creates a step that deploys inline text content to the project. Like
step_file() but takes a character vector instead of a source file path.
Arguments
- content
Character vector of lines to deploy (one element per line).
character(0)is allowed except withstrategy = "merge_json".- dest
Path to the destination, relative to the project root.
- strategy
How to handle a pre-existing destination file. One of
"overwrite","skip","union","append", or"merge_json".