Prints the R code that would reproduce the given theme via cat(), and
returns the code invisibly as a single character string.
Arguments
- theme
A
prefab_themeobject. Unlikeuse_theme(),create_project(), andlaunch_project(), this does not accept a path to a directory of template files; passtheme_from_dir()the path instead.