Skip to contents

Prints the R code that would reproduce the given theme via cat(), and returns the code invisibly as a single character string.

Usage

theme_code(theme)

Arguments

theme

A prefab_theme object.

Value

The generated R code as a single character string (invisibly).