Prints the R code that would reproduce the given theme via cat(), and
returns the code invisibly as a single character string.
Prints the R code that would reproduce the given theme via cat(), and
returns the code invisibly as a single character string.